@@ -61,8 +61,8 @@ IGMPv2 message format   http://www.faqs.org/rfcs/rfc2236.html
     """
     p += pay
     if self.chksum is None:
-      ck = checksum(p)
-      p = p[:2]+bytes(ck>>8)+bytes(ck&0xff)+p[4:]
+      ck = checksum(p[:2]+p[4:])
+      p = p[:2]+ck.to_bytes(2, 'big')+p[4:]
     return p
 
 #--------------------------------------------------------------------------
